@@ -21,11 +21,6 @@
 #include "sd_bus_internals.h"
 
 // Python functions and objects
-PyObject* unmapped_error_exception = NULL;
-PyObject* dbus_error_to_exception_dict = NULL;
-PyObject* exception_to_dbus_error_dict = NULL;
-PyObject* exception_base = NULL;
-PyObject* exception_lib = NULL;
 PyObject* asyncio_get_running_loop = NULL;
 PyObject* asyncio_queue_class = NULL;
 PyObject* is_coroutine_function = NULL;
@@ -41,6 +36,17 @@ PyObject* extend_str = NULL;
 PyObject* append_str = NULL;
 PyObject* call_soon_str = NULL;
 PyObject* create_task_str = NULL;
+// Exceptions
+PyObject* exception_base = NULL;
+PyObject* unmapped_error_exception = NULL;
+PyObject* exception_lib = NULL;
+PyObject* exception_request_name = NULL;                // Base to any request name exception
+PyObject* exception_request_name_in_queue = NULL;       // Queued up to acquire name
+PyObject* exception_request_name_exists = NULL;         // Someone already owns the name
+PyObject* exception_request_name_already_owner = NULL;  // Already an owner of the name
+
+PyObject* dbus_error_to_exception_dict = NULL;
+PyObject* exception_to_dbus_error_dict = NULL;
 
 // SdBusSlot
 
@@ -123,6 +129,27 @@ PyMODINIT_FUNC PyInit_sd_bus_internals(void) {
         SD_BUS_PY_INIT_ADD_OBJECT("SdBusLibraryError", library_exception);
         exception_lib = library_exception;
 
+        // Request name exceptions
+        PyObject* request_name_exception CLEANUP_PY_OBJECT =
+            CALL_PYTHON_AND_CHECK(PyErr_NewException("sd_bus_internals.SdBusRequestNameError", new_base_exception, NULL));
+        SD_BUS_PY_INIT_ADD_OBJECT("SdBusRequestNameError", request_name_exception);
+        exception_request_name = request_name_exception;
+        // Request name but in queue
+        PyObject* request_name_in_queue_exception CLEANUP_PY_OBJECT =
+            CALL_PYTHON_AND_CHECK(PyErr_NewException("sd_bus_internals.SdBusRequestNameInQueueError", request_name_exception, NULL));
+        SD_BUS_PY_INIT_ADD_OBJECT("SdBusRequestNameInQueueError", request_name_in_queue_exception);
+        exception_request_name_in_queue = request_name_in_queue_exception;
+        // Request name but someone already owns the name
+        PyObject* request_name_exists_exception CLEANUP_PY_OBJECT =
+            CALL_PYTHON_AND_CHECK(PyErr_NewException("sd_bus_internals.SdBusRequestNameExistsError", request_name_exception, NULL));
+        SD_BUS_PY_INIT_ADD_OBJECT("SdBusRequestNameExistsError", request_name_exists_exception);
+        exception_request_name_exists = request_name_exists_exception;
+        // Request name but we already own the name
+        PyObject* request_name_already_owner_exception CLEANUP_PY_OBJECT =
+            CALL_PYTHON_AND_CHECK(PyErr_NewException("sd_bus_internals.SdBusRequestNameAlreadyOwnerError", request_name_exception, NULL));
+        SD_BUS_PY_INIT_ADD_OBJECT("SdBusRequestNameAlreadyOwnerError", request_name_already_owner_exception);
+        exception_request_name_already_owner = request_name_already_owner_exception;
+
         PyObject* asyncio_module = CALL_PYTHON_AND_CHECK(PyImport_ImportModule("asyncio"));
 
         asyncio_get_running_loop = CALL_PYTHON_AND_CHECK(PyObject_GetAttrString(asyncio_module, "get_running_loop"));
@@ -154,6 +181,10 @@ PyMODINIT_FUNC PyInit_sd_bus_internals(void) {
         CALL_PYTHON_INT_CHECK(PyModule_AddIntConstant(m, "DbusPropertyExplicitFlag", SD_BUS_VTABLE_PROPERTY_EXPLICIT));
         CALL_PYTHON_INT_CHECK(PyModule_AddIntConstant(m, "DbusSensitiveFlag", SD_BUS_VTABLE_SENSITIVE));
 
+        CALL_PYTHON_INT_CHECK(PyModule_AddIntConstant(m, "NameAllowReplacementFlag", SD_BUS_NAME_ALLOW_REPLACEMENT));
+        CALL_PYTHON_INT_CHECK(PyModule_AddIntConstant(m, "NameReplaceExistingFlag", SD_BUS_NAME_REPLACE_EXISTING));
+        CALL_PYTHON_INT_CHECK(PyModule_AddIntConstant(m, "NameQueueFlag", SD_BUS_NAME_QUEUE));
+
         Py_INCREF(m);
         return m;
 }
