@@ -1,6 +1,6 @@
 # SPDX-License-Identifier: LGPL-2.1-or-later
 
-# Copyright (C) 2020, 2021 igo95862
+# Copyright (C) 2020-2023 igo95862
 
 # This file is part of python-sdbus
 
@@ -22,10 +22,19 @@ from __future__ import annotations
 
 from asyncio import Event, get_running_loop, sleep, wait_for
 from asyncio.subprocess import create_subprocess_exec
-from typing import Tuple
+from typing import Tuple, cast
 from unittest import SkipTest
 
 from sdbus.dbus_common_funcs import PROPERTY_FLAGS_MASK, count_bits
+from sdbus.dbus_proxy_async_interfaces import DBUS_PROPERTIES_CHANGED_TYPING
+from sdbus.exceptions import (
+    DbusFailedError,
+    DbusFileExistsError,
+    DbusPropertyReadOnlyError,
+    DbusUnknownObjectError,
+    SdBusLibraryError,
+    SdBusUnmappedMessageError,
+)
 from sdbus.sd_bus_internals import (
     DBUS_ERROR_TO_EXCEPTION,
     DbusDeprecatedFlag,
@@ -34,15 +43,11 @@ from sdbus.sd_bus_internals import (
     is_interface_name_valid,
 )
 from sdbus.unittest import IsolatedDbusTestCase
+from sdbus.utils import parse_properties_changed
 
 from sdbus import (
-    DbusFailedError,
-    DbusFileExistsError,
     DbusInterfaceCommonAsync,
     DbusNoReplyFlag,
-    DbusUnknownObjectError,
-    SdBusLibraryError,
-    SdBusUnmappedMessageError,
     dbus_method_async,
     dbus_method_async_override,
     dbus_property_async,
@@ -92,6 +97,7 @@ class TestInterface(DbusInterfaceCommonAsync,
         self.test_string = 'test_property'
         self.test_string_read = 'read'
         self.test_no_reply_string = 'no'
+        self.property_private = 100
         self.no_reply_sync = Event()
 
     @dbus_method_async("s", "s")
@@ -128,6 +134,14 @@ class TestInterface(DbusInterfaceCommonAsync,
     def test_property_read_only(self) -> str:
         return self.test_string_read
 
+    @dbus_property_async("x")
+    def test_property_private(self) -> int:
+        return self.property_private
+
+    @test_property_private.setter_private
+    def test_private_setter(self, new_value: int) -> None:
+        self.property_private = new_value
+
     @dbus_method_async("sb", "s")
     async def kwargs_function(
             self,
@@ -198,6 +212,10 @@ class TestInterface(DbusInterfaceCommonAsync,
     async def looong_method(self) -> None:
         await sleep(100)
 
+    @dbus_signal_async()
+    def empty_signal(self) -> None:
+        raise NotImplementedError
+
 
 class DbusErrorTest(DbusFailedError):
     dbus_error_name = 'org.example.Error'
@@ -802,3 +820,86 @@ class TestProxy(IsolatedDbusTestCase):
                 await test_object_connection.properties_get_all_dict()
             )['test_property'],
         )
+
+    async def test_empty_signal(self) -> None:
+        test_object, test_object_connection = initialize_object()
+
+        loop = get_running_loop()
+
+        ai_dbus = test_object_connection.empty_signal.__aiter__()
+        aw_dbus = ai_dbus.__anext__()
+        q = test_object.empty_signal._get_local_queue()
+
+        loop.call_at(0, test_object.empty_signal.emit, None)
+
+        self.assertIsNone(await wait_for(aw_dbus, timeout=1))
+
+        self.assertIsNone(await wait_for(q.get(), timeout=1))
+
+    async def test_properties_changed(self) -> None:
+        test_object, test_object_connection = initialize_object()
+
+        test_str = 'should_be_emited'
+
+        q = await test_object_connection.properties_changed._get_dbus_queue()
+
+        async def set_property() -> None:
+            await test_object_connection.test_property.set_async(test_str)
+
+        await set_property()
+
+        properties_changed_data = cast(
+            DBUS_PROPERTIES_CHANGED_TYPING,
+            (await q.get()).get_contents(),
+        )
+
+        parsed_dict_from_class = parse_properties_changed(
+            TestInterface, properties_changed_data)
+        self.assertEqual(
+            test_str,
+            parsed_dict_from_class['test_property'],
+        )
+
+        parsed_dict_from_object = parse_properties_changed(
+            test_object_connection, properties_changed_data)
+        self.assertEqual(
+            test_str,
+            parsed_dict_from_object['test_property'],
+        )
+
+        properties_changed_data[2].append('invalidated_property')
+        parsed_dict_with_invalidation = parse_properties_changed(
+            test_object, properties_changed_data,
+            on_unknown_member='reuse',
+        )
+        self.assertIsNone(
+            parsed_dict_with_invalidation['invalidated_property'])
+
+    async def test_property_private_setter(self) -> None:
+        test_object, test_object_connection = initialize_object()
+
+        new_value = 200
+        self.assertNotEqual(
+            await test_object_connection.test_property_private,
+            new_value
+        )
+
+        with self.assertRaises(DbusPropertyReadOnlyError):
+            await test_object_connection.test_property_private.set_async(
+                new_value)
+
+        q = await test_object_connection.properties_changed._get_dbus_queue()
+
+        await test_object.test_property_private.set_async(new_value)
+
+        self.assertEqual(
+            await test_object_connection.test_property_private,
+            new_value
+        )
+
+        changed_properties = cast(
+            DBUS_PROPERTIES_CHANGED_TYPING,
+            (await q.get()).get_contents(),
+        )
+
+        self.assertIn('TestPropertyPrivate', changed_properties[1])
